@@ -4,7 +4,7 @@
 
 (defvar generated-autoload-file)
 (defvar command-line-args-left)
-(defun generate-autoloads ()
+(defun erc-generate-autoloads ()
   (interactive)
   (require 'autoload)
   (setq generated-autoload-file (car command-line-args-left))
@@ -14,45 +14,54 @@
 (provide 'erc-auto)
 ;;; Generated autoloads follow (made by autoload.el).
 
-;;;### (autoloads (erc-select) "erc" "erc.el" (17143 46861))
+;;;### (autoloads (erc-select erc-select-read-args) "erc" "erc.el"
+;;;;;;  (17370 60582))
 ;;; Generated autoloads from erc.el
 
+(autoload (quote erc-select-read-args) "erc" "\
+Prompt the user for values of nick, server, port, and password.
+
+\(fn)" nil nil)
+
 (autoload (quote erc-select) "erc" "\
-Select connection parameters and run ERC. 
-Non-interactively, it takes keyword arguments 
+Select connection parameters and run ERC.
+Non-interactively, it takes keyword arguments
    (server (erc-compute-server))
    (port   (erc-compute-port))
    (nick   (erc-compute-nick))
-   password 
+   password
    (full-name (erc-compute-full-name)))
-That is, if called with (erc-select :server \"irc.freenode.net\" :full-name \"Harry S Truman\") , 
-server and full-name will be set to those values, whereas erc-compute-port, erc-compute-nick and 
-erc-compute-full-name will be invoked for those parameters' values
+
+That is, if called with
+   (erc-select :server \"irc.freenode.net\" :full-name \"Harry S Truman\")
+server and full-name will be set to those values, whereas
+erc-compute-port, erc-compute-nick and erc-compute-full-name will
+be invoked for those parameters' values
 
 \(fn &key (SERVER (erc-compute-server)) (PORT (erc-compute-port)) (NICK (erc-compute-nick)) PASSWORD (FULL-NAME (erc-compute-full-name)))" t nil)
 
 ;;;***
 
-;;;### (autoloads nil "erc-autojoin" "erc-autojoin.el" (17108 18491))
+;;;### (autoloads nil "erc-autojoin" "erc-autojoin.el" (17340 28046))
 ;;; Generated autoloads from erc-autojoin.el
  (autoload 'erc-autojoin-mode "erc-autojoin" nil t)
 
 ;;;***
 
-;;;### (autoloads nil "erc-bbdb" "erc-bbdb.el" (17108 18491))
+;;;### (autoloads nil "erc-bbdb" "erc-bbdb.el" (17364 23774))
 ;;; Generated autoloads from erc-bbdb.el
  (autoload 'erc-bbdb-mode "erc-bbdb")
 
 ;;;***
 
-;;;### (autoloads nil "erc-button" "erc-button.el" (17108 18491))
+;;;### (autoloads nil "erc-button" "erc-button.el" (17365 10674))
 ;;; Generated autoloads from erc-button.el
  (autoload 'erc-button-mode "erc-button" nil t)
 
 ;;;***
 
 ;;;### (autoloads (erc-chess-ctcp-query-handler erc-cmd-CHESS) "erc-chess"
-;;;;;;  "erc-chess.el" (17108 18491))
+;;;;;;  "erc-chess.el" (17340 28046))
 ;;; Generated autoloads from erc-chess.el
 
 (defvar erc-ctcp-query-CHESS-hook (quote (erc-chess-ctcp-query-handler)))
@@ -70,14 +79,14 @@ Not documented
 
 ;;;***
 
-;;;### (autoloads nil "erc-compat" "erc-compat.el" (17053 16729))
+;;;### (autoloads nil "erc-compat" "erc-compat.el" (17363 44956))
 ;;; Generated autoloads from erc-compat.el
  (autoload 'erc-define-minor-mode "erc-compat")
 
 ;;;***
 
 ;;;### (autoloads (erc-complete) "erc-complete" "erc-complete.el"
-;;;;;;  (17108 18491))
+;;;;;;  (17340 28046))
 ;;; Generated autoloads from erc-complete.el
 
 (autoload (quote erc-complete) "erc-complete" "\
@@ -90,7 +99,7 @@ This function is obsolete, use `erc-pcomplete' instead.
 ;;;***
 
 ;;;### (autoloads (erc-ctcp-query-DCC pcomplete/erc-mode/DCC erc-cmd-DCC)
-;;;;;;  "erc-dcc" "erc-dcc.el" (17108 18491))
+;;;;;;  "erc-dcc" "erc-dcc.el" (17364 23774))
 ;;; Generated autoloads from erc-dcc.el
 
 (autoload (quote erc-cmd-DCC) "erc-dcc" "\
@@ -122,7 +131,7 @@ that subcommand.
 ;;;;;;  erc-ezb-add-session erc-ezb-end-of-session-list erc-ezb-init-session-list
 ;;;;;;  erc-ezb-identify erc-ezb-notice-autodetect erc-ezb-lookup-action
 ;;;;;;  erc-ezb-get-login erc-cmd-ezb) "erc-ezbounce" "erc-ezbounce.el"
-;;;;;;  (17108 18491))
+;;;;;;  (17363 44957))
 ;;; Generated autoloads from erc-ezbounce.el
 
 (autoload (quote erc-cmd-ezb) "erc-ezbounce" "\
@@ -184,7 +193,7 @@ Add EZBouncer convenience functions to ERC.
 
 ;;;***
 
-;;;### (autoloads (erc-fill) "erc-fill" "erc-fill.el" (17108 18491))
+;;;### (autoloads (erc-fill) "erc-fill" "erc-fill.el" (17363 44957))
 ;;; Generated autoloads from erc-fill.el
  (autoload 'erc-fill-mode "erc-fill" nil t)
 
@@ -197,7 +206,7 @@ You can put this on `erc-insert-modify-hook' and/or `erc-send-modify-hook'.
 ;;;***
 
 ;;;### (autoloads (erc-create-imenu-index) "erc-imenu" "erc-imenu.el"
-;;;;;;  (17108 18491))
+;;;;;;  (17340 28046))
 ;;; Generated autoloads from erc-imenu.el
 
 (autoload (quote erc-create-imenu-index) "erc-imenu" "\
@@ -208,7 +217,7 @@ Not documented
 ;;;***
 
 ;;;### (autoloads (erc-chanlist erc-cmd-LIST) "erc-list" "erc-list.el"
-;;;;;;  (17108 18491))
+;;;;;;  (17367 50276))
 ;;; Generated autoloads from erc-list.el
 
 (autoload (quote erc-cmd-LIST) "erc-list" "\
@@ -228,7 +237,7 @@ to RFC and send the LIST header (#321) at start of list transmission.
 ;;;***
 
 ;;;### (autoloads (erc-save-buffer-in-logs erc-logging-enabled) "erc-log"
-;;;;;;  "erc-log.el" (17108 18491))
+;;;;;;  "erc-log.el" (17363 44957))
 ;;; Generated autoloads from erc-log.el
  (autoload 'erc-log-mode "erc-log" nil t)
 
@@ -259,8 +268,8 @@ You can save every individual message by putting this function on
 
 ;;;### (autoloads (erc-delete-dangerous-host erc-add-dangerous-host
 ;;;;;;  erc-delete-keyword erc-add-keyword erc-delete-fool erc-add-fool
-;;;;;;  erc-delete-pal erc-add-pal) "erc-match" "erc-match.el" (17108
-;;;;;;  18491))
+;;;;;;  erc-delete-pal erc-add-pal) "erc-match" "erc-match.el" (17368
+;;;;;;  2972))
 ;;; Generated autoloads from erc-match.el
  (autoload 'erc-match-mode "erc-match")
 
@@ -307,7 +316,7 @@ Delete dangerous-host interactively to `erc-dangerous-hosts'.
 ;;;***
 
 ;;;### (autoloads (erc-server-select erc-determine-network) "erc-nets"
-;;;;;;  "erc-nets.el" (17108 18491))
+;;;;;;  "erc-nets.el" (17363 44957))
 ;;; Generated autoloads from erc-nets.el
 
 (autoload (quote erc-determine-network) "erc-nets" "\
@@ -325,7 +334,7 @@ Interactively select a server to connect to using `erc-server-alist'.
 ;;;***
 
 ;;;### (autoloads (erc-cmd-WHOLEFT) "erc-netsplit" "erc-netsplit.el"
-;;;;;;  (17108 18491))
+;;;;;;  (17363 44957))
 ;;; Generated autoloads from erc-netsplit.el
  (autoload 'erc-netsplit-mode "erc-netsplit")
 
@@ -337,7 +346,7 @@ Show who's gone.
 ;;;***
 
 ;;;### (autoloads (erc-nickserv-identify erc-nickserv-identify-mode)
-;;;;;;  "erc-nickserv" "erc-nickserv.el" (17108 18491))
+;;;;;;  "erc-nickserv" "erc-nickserv.el" (17363 44957))
 ;;; Generated autoloads from erc-nickserv.el
  (autoload 'erc-services-mode "erc-nickserv" nil t)
 
@@ -355,7 +364,7 @@ When called interactively, read the password using `read-passwd'.
 ;;;***
 
 ;;;### (autoloads (pcomplete/erc-mode/NOTIFY erc-cmd-NOTIFY) "erc-notify"
-;;;;;;  "erc-notify.el" (16958 31181))
+;;;;;;  "erc-notify.el" (17363 948))
 ;;; Generated autoloads from erc-notify.el
  (autoload 'erc-notify-mode "erc-notify" nil t)
 
@@ -373,38 +382,38 @@ Not documented
 
 ;;;***
 
-;;;### (autoloads nil "erc-page" "erc-page.el" (16889 18411))
+;;;### (autoloads nil "erc-page" "erc-page.el" (17340 28046))
 ;;; Generated autoloads from erc-page.el
  (autoload 'erc-page-mode "erc-page")
 
 ;;;***
 
-;;;### (autoloads nil "erc-pcomplete" "erc-pcomplete.el" (17108 18491))
+;;;### (autoloads nil "erc-pcomplete" "erc-pcomplete.el" (17363 44957))
 ;;; Generated autoloads from erc-pcomplete.el
  (autoload 'erc-completion-mode "erc-pcomplete" nil t)
 
 ;;;***
 
-;;;### (autoloads nil "erc-replace" "erc-replace.el" (17108 18491))
+;;;### (autoloads nil "erc-replace" "erc-replace.el" (17340 28046))
 ;;; Generated autoloads from erc-replace.el
  (autoload 'erc-replace-mode "erc-replace")
 
 ;;;***
 
-;;;### (autoloads nil "erc-ring" "erc-ring.el" (17108 18491))
+;;;### (autoloads nil "erc-ring" "erc-ring.el" (17340 28046))
 ;;; Generated autoloads from erc-ring.el
  (autoload 'erc-ring-mode "erc-ring" nil t)
 
 ;;;***
 
-;;;### (autoloads nil "erc-sound" "erc-sound.el" (16889 18412))
+;;;### (autoloads nil "erc-sound" "erc-sound.el" (17340 28046))
 ;;; Generated autoloads from erc-sound.el
  (autoload 'erc-sound-mode "erc-sound")
 
 ;;;***
 
 ;;;### (autoloads (erc-speedbar-browser) "erc-speedbar" "erc-speedbar.el"
-;;;;;;  (17108 18491))
+;;;;;;  (17340 28046))
 ;;; Generated autoloads from erc-speedbar.el
 
 (autoload (quote erc-speedbar-browser) "erc-speedbar" "\
@@ -415,13 +424,19 @@ This will add a speedbar major display mode.
 
 ;;;***
 
-;;;### (autoloads nil "erc-stamp" "erc-stamp.el" (17108 18491))
+;;;### (autoloads nil "erc-spelling" "erc-spelling.el" (17362 21862))
+;;; Generated autoloads from erc-spelling.el
+ (autoload 'erc-spelling-mode "erc-spelling" nil t)
+
+;;;***
+
+;;;### (autoloads nil "erc-stamp" "erc-stamp.el" (17369 29178))
 ;;; Generated autoloads from erc-stamp.el
  (autoload 'erc-timestamp-mode "erc-stamp" nil t)
 
 ;;;***
 
-;;;### (autoloads nil "erc-track" "erc-track.el" (17053 16729))
+;;;### (autoloads nil "erc-track" "erc-track.el" (17365 6231))
 ;;; Generated autoloads from erc-track.el
  (autoload 'erc-track-mode "erc-track" nil t)
  (autoload 'erc-track-when-inactive-mode "erc-track" nil t)
@@ -429,7 +444,7 @@ This will add a speedbar major display mode.
 ;;;***
 
 ;;;### (autoloads (erc-truncate-buffer erc-truncate-buffer-to-size)
-;;;;;;  "erc-truncate" "erc-truncate.el" (16889 18412))
+;;;;;;  "erc-truncate" "erc-truncate.el" (17363 2616))
 ;;; Generated autoloads from erc-truncate.el
  (autoload 'erc-truncate-mode "erc-truncate" nil t)
 
@@ -448,8 +463,8 @@ Meant to be used in hooks, like `erc-insert-post-hook'.
 
 ;;;***
 
-;;;### (autoloads (erc-xdcc-add-file) "erc-xdcc" "erc-xdcc.el" (16889
-;;;;;;  18412))
+;;;### (autoloads (erc-xdcc-add-file) "erc-xdcc" "erc-xdcc.el" (17340
+;;;;;;  28046))
 ;;; Generated autoloads from erc-xdcc.el
 
 (autoload (quote erc-xdcc-add-file) "erc-xdcc" "\
@@ -461,11 +476,12 @@ Add a file to `erc-xdcc-files'.
 
 ;;;### (autoloads nil nil ("erc-backend.el" "erc-goodies.el" "erc-ibuffer.el"
 ;;;;;;  "erc-identd.el" "erc-lang.el" "erc-maint.el" "erc-menu.el"
-;;;;;;  "erc-nicklist.el" "erc-speak.el") (17143 47545 759572))
+;;;;;;  "erc-nicklist.el" "erc-speak.el" "erc-viper.el") (17370 60587
+;;;;;;  118372))
 
 ;;;***
 
-;;;### (autoloads nil "erc-autoaway" "erc-autoaway.el" (17053 16729))
+;;;### (autoloads nil "erc-autoaway" "erc-autoaway.el" (17363 44956))
 ;;; Generated autoloads from erc-autoaway.el
  (autoload 'erc-autoaway-mode "erc-autoaway")
 
