@@ -1,6 +1,6 @@
 ;;; erc-bbdb.el --- Integrating the BBDB into ERC
 
-;; Copyright (C) 2001,2002,2004 Free Software Foundation, Inc.
+;; Copyright (C) 2001,2002,2004,2005 Free Software Foundation, Inc.
 
 ;; Author: Andreas Fuchs <asf@void.at>
 ;; Maintainer: Mario Lang <mlang@delysid.org>
@@ -16,9 +16,9 @@
 ;; License for more details.
 ;;
 ;; You should have received a copy of the GNU General Public License
-;; along with GNU Emacs; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-;; Boston, MA 02111-1307, USA.
+;; along with GNU Emacs; see the file COPYING. If not, write to the
+;; Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+;; Boston, MA 02110-1301 USA
 
 ;;; Commentary:
 
@@ -33,6 +33,13 @@
 ;; Andreas Fuchs <asf@void.at> wrote zenirc-bbdb-whois.el, which was
 ;; adapted for ERC by Mario Lang <mlang@delysid.org>.
 
+;; Changes by Edgar Gonçalves <edgar.goncalves@inesc-id.pt>
+;; May 31 2005:
+;;     - new variable: erc-bbdb-bitlbee-name-field - the field name for the
+;;       msn/icq/etc nick
+;;     - nick doesn't go the the name. now it asks for an existing record to
+;;       merge with. If none, then create a new one with the nick as name.
+
 ;;; Code:
 
 (require 'erc)
@@ -41,7 +48,7 @@
 (require 'bbdb-gui)
 (require 'bbdb-hooks)
 
-(defconst erc-bbdb-version "$Revision: 1.23.2.2 $"
+(defconst erc-bbdb-version "$Revision: 1.31 $"
   "ERC BBDB revision.")
 
 (defgroup erc-bbdb nil
@@ -88,22 +95,32 @@ or a person joined a channel visible on any frame."
   :type 'symbol)
 
 (defcustom erc-bbdb-irc-highlight-field 'irc-highlight
-  "The notes field name to use for highlighting of a person's messages"
+  "The notes field name to use for highlighting a person's messages."
+  :group 'erc-bbdb
+  :type 'symbol)
+
+(defcustom erc-bbdb-bitlbee-name-field 'bitlbee-name
+  "The notes field name to use for annotating bitlbee displayed name.
+This is the name that a bitlbee (AIM/MSN/ICQ) contact provides as
+their \"displayed name\"."
   :group 'erc-bbdb
   :type 'symbol)
 
 (defcustom erc-bbdb-elide-display nil
-  "*If t, show BBDB popup buffer elided"
+  "*If t, show BBDB popup buffer elided."
   :group 'erc-bbdb
   :type 'boolean)
 
-(defun erc-bbdb-search-name-and-create (create-p name nick finger-host)
+(defun erc-bbdb-search-name-and-create (create-p name nick finger-host silent)
   (let* ((ircnick (cons erc-bbdb-irc-nick-field (concat "^"
 							(regexp-quote nick))))
 	 (finger (cons bbdb-finger-host-field (regexp-quote finger-host)))
 	 (record (or (bbdb-search (bbdb-records) nil nil nil ircnick)
 		     (and name (bbdb-search-simple name nil))
 		     (bbdb-search (bbdb-records) nil nil nil finger)
+		     (unless silent
+		       (bbdb-completing-read-one-record
+			"Merge using record of: "))
 		     (when create-p
 		       (bbdb-create-internal (or name
 						 "John Doe")
@@ -124,14 +141,16 @@ or a person joined a channel visible on any frame."
 							   'visible))))))
       (bbdb-display-records (list record)))))
 
-(defun erc-bbdb-insinuate-and-show-entry (create-p proc nick name finger-host &optional chan new-nick)
+(defun erc-bbdb-insinuate-and-show-entry (create-p proc nick name finger-host silent &optional chan new-nick)
   (let ((record (erc-bbdb-search-name-and-create
-		 create-p name nick finger-host)))
+		 create-p nil nick finger-host silent))) ;; don't search for a name
     (when record
       (bbdb-annotate-notes record (or new-nick nick) erc-bbdb-irc-nick-field)
       (bbdb-annotate-notes record finger-host bbdb-finger-host-field)
+      (and name
+	   (bbdb-annotate-notes record name erc-bbdb-bitlbee-name-field t))
       (and chan
-           (not (eq chan t))
+	   (not (eq chan t))
 	   (bbdb-annotate-notes record chan erc-bbdb-irc-channel-field))
       (erc-bbdb-highlight-record record)
       (erc-bbdb-show-entry record chan proc))))
@@ -141,10 +160,10 @@ or a person joined a channel visible on any frame."
 	(nick (second (erc-response.command-args parsed)))
 	(name (erc-response.contents parsed))
 	(finger-host (concat (third (erc-response.command-args parsed))
-                             "@"
-                             (fourth (erc-response.command-args parsed)))))
+			     "@"
+			     (fourth (erc-response.command-args parsed)))))
     (erc-bbdb-insinuate-and-show-entry erc-bbdb-auto-create-on-whois-p proc
-				       nick name finger-host t)))
+				       nick name finger-host nil t)))
 
 (defun erc-bbdb-JOIN (proc parsed)
   (let* ((sender (erc-parse-user (erc-response.sender parsed)))
@@ -154,7 +173,7 @@ or a person joined a channel visible on any frame."
 	     (finger-host (concat (nth 1 sender) "@" (nth 2 sender))))
 	  (erc-bbdb-insinuate-and-show-entry
 	   erc-bbdb-auto-create-on-join-p proc
-	   nick nil finger-host channel)))))
+	   nick nil finger-host t channel)))))
 
 (defun erc-bbdb-NICK (proc parsed)
   "Annotate new nick name to a record in case it already exists."
@@ -164,7 +183,7 @@ or a person joined a channel visible on any frame."
       (let* ((finger-host (concat (nth 1 sender) "@" (nth 2 sender))))
 	(erc-bbdb-insinuate-and-show-entry
 	 erc-bbdb-auto-create-on-nick-p proc
-	 nick nil finger-host nil (erc-response.contents parsed))))))
+	 nick nil finger-host t nil (erc-response.contents parsed))))))
 
 (defun erc-bbdb-init-highlighting-hook-fun (proc parsed)
   (erc-bbdb-init-highlighting))
@@ -222,3 +241,8 @@ counterparts `erc-pals', `erc-dangerous-hosts' and `erc-fools'."
 (provide 'erc-bbdb)
 
 ;;; erc-bbdb.el ends here
+;;
+;; Local Variables:
+;; indent-tabs-mode: t
+;; tab-width: 8
+;; End:
