@@ -1,6 +1,6 @@
 ;;; erc-fill.el --- Filling IRC messages in various ways
 
-;; Copyright (C) 2002  Alex Schroeder
+;; Copyright (C) 2001,2002,2003,2004 Free Software Foundation, Inc.
 
 ;; Author: Andreas Fuchs <asf@void.at>
 ;;         Mario Lang <mlang@delysid.org>
@@ -19,9 +19,9 @@
 ;; GNU General Public License for more details.
 
 ;; You should have received a copy of the GNU General Public License
-;; along with GNU Emacs; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-;; Boston, MA 02111-1307, USA.
+;; along with GNU Emacs; see the file COPYING. If not, write to the
+;; Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+;; Boston, MA 02110-1301 USA
 
 ;; This file is not part of GNU Emacs.
 
@@ -36,7 +36,7 @@
 (require 'erc)
 (require 'erc-stamp); for the timestamp stuff
 
-(defconst erc-fill-version "$Revision: 1.19 $"
+(defconst erc-fill-version "$Revision: 1.32 $"
   "ERC fill revision.")
 
 (defgroup erc-fill nil
@@ -64,7 +64,7 @@ filled."
 (defun erc-fill-disable ()
   "Cleanup hooks, disable `erc-fill-mode'."
   (interactive)
-  (remove-hook 'erc-insert-modify-hook 'erc-fill-static)
+  (remove-hook 'erc-insert-modify-hook 'erc-fill)
   (remove-hook 'erc-send-modify-hook 'erc-fill))
 
 (defcustom erc-fill-prefix nil
@@ -99,8 +99,8 @@ function.  Narrowing to the region in question is in effect while your
 function is called."
   :group 'erc-fill
   :type '(choice (const :tag "Variable Filling" erc-fill-variable)
-		 (const :tag "Static Filling" erc-fill-static)
-		 function))
+                 (const :tag "Static Filling" erc-fill-static)
+                 function))
 
 (defcustom erc-fill-static-center 27
   "Column around which all statically filled messages will be
@@ -110,11 +110,18 @@ nick names right and text left."
   :group 'erc-fill
   :type 'integer)
 
-(defcustom erc-fill-column 70
+(defcustom erc-fill-variable-maximum-indentation 17
+  "If we indent a line after a long nick, don't indent more then this
+characters. Set to nil to disable."
+  :group 'erc-fill
+  :type 'integer)
+
+(defcustom erc-fill-column 78
   "The column at which a filled paragraph is broken."
   :group 'erc-fill
   :type 'integer)
 
+;;;###autoload
 (defun erc-fill ()
   "Fill a region using the function referenced in `erc-fill-function'.
 You can put this on `erc-insert-modify-hook' and/or `erc-send-modify-hook'."
@@ -125,65 +132,69 @@ You can put this on `erc-insert-modify-hook' and/or `erc-send-modify-hook'."
 (defun erc-fill-static ()
   "Fills a text such that messages start at column `erc-fill-static-center'."
   (save-match-data
-    (let* ((white-space-str " \t")
-	   (white-space-lst (string-to-list white-space-str))
-	   (white-space-re  (concat "[" white-space-str "]")))
-      (goto-char (point-min))
-      (let* ((nick (when (looking-at "^\\(\\S-+\\)\\( .*\\)$")
-		     (match-string 1)))
-	     (message-text (and nick (match-string 2)))
-	     (text-start   (max 0 (- erc-fill-static-center (length nick)))))
-	(when (and nick message-text)
-	  (insert (make-string text-start ? ))
-	  (let ((fill-column erc-fill-column)
-		(erc-fill-prefix (make-string text-start ? )))
-	    (erc-fill-variable)
-	    (goto-char (point-min))
-	    (let ((lines-to-go (erc-count-lines)))
-	      (when (>= lines-to-go 1) ; we have more than one line to fill
-		(save-restriction
-		  (narrow-to-region (progn (forward-line)
-					   (point))
-				    (point-max))
-		  (let ((fill-column (- fill-column (string-width nick))))
-		    (erc-fill-variable)) ; first re-fill for
-					; "smaller" margin
-		  (goto-char (point-min)) ; now indent behind nick
-		  (while (> lines-to-go 0)
-		    (insert (make-string (1+ (length nick)) ? ))
-		    (forward-line)
-		    (setq lines-to-go (1- lines-to-go))))))
-	    (let* ((parsed-posn (text-property-not-all (point-min) (point-max) 'erc-parsed nil))
-		   (parsed-prop (when parsed-posn
-				  (get-text-property parsed-posn 'erc-parsed))))
-	      (put-text-property (point-min) (point-max) 'erc-parsed parsed-prop))))))))
-
-(defun erc-count-lines ()
-  "Count the lines that lie between (point) and the end of the buffer."
-  (let ((i 0)
-	(point-before (point)))
-    (while (not (= 1 (forward-line)))
-      (setq i (1+ i)))
-    (goto-char point-before)
-    (max 0 (1- i))))
+    (goto-char (point-min))
+    (looking-at "^\\(\\S-+\\)")
+    (let ((nick (match-string 1)))
+        (let ((fill-column (- erc-fill-column (erc-timestamp-offset)))
+              (fill-prefix (make-string erc-fill-static-center 32)))
+          (insert (make-string (max 0 (- erc-fill-static-center
+                                         (length nick) 1))
+                               32))
+          (erc-fill-regarding-timestamp))
+        (erc-restore-text-properties))))
 
 (defun erc-fill-variable ()
-  "Fill region from START to END. START and END should be markers."
+  "Fill from `point-min' to `point-max'."
   (let ((fill-prefix erc-fill-prefix)
         (fill-column (or erc-fill-column fill-column)))
-    (unless fill-prefix
-      (goto-char (point-min))
-      (when (looking-at "\\(\\S-+ \\)")
-	(let ((len (length (match-string 1))))
-      (if (and (boundp 'erc-timestamp-format)
-               erc-timestamp-format
-               (eq erc-insert-timestamp-function 'erc-insert-timestamp-left)
-               (not erc-hide-timestamps))
-          (setq len (+ len 
-                       (length (format-time-string erc-timestamp-format)))))
-	  (setq fill-prefix (make-string len ? )))))
-    (fill-region (point-min) (point-max) t t)))
+    (goto-char (point-min))
+    (if fill-prefix
+        (let ((first-line-offset (make-string (erc-timestamp-offset) 32)))
+          (insert first-line-offset)
+          (fill-region (point-min) (point-max) t t)
+          (goto-char (point-min))
+          (delete-char (length first-line-offset)))
+      (save-match-data
+        (let* ((nickp (looking-at "^\\(\\S-+\\)"))
+               (nick (if nickp
+                         (match-string 1)
+                       ""))
+               (fill-column (- erc-fill-column (erc-timestamp-offset)))
+               (fill-prefix (make-string (min (+ 1 (length nick))
+                                              (- fill-column 1)
+                                              (or erc-fill-variable-maximum-indentation
+                                                  fill-column))
+                                         32)))
+          (erc-fill-regarding-timestamp))))
+    (erc-restore-text-properties)))
+
+(defun erc-fill-regarding-timestamp ()
+  "Fills a text such that messages start at column `erc-fill-static-center'."
+  (fill-region (point-min) (point-max) t t)
+  (goto-char (point-min))
+  (forward-line)
+  (indent-rigidly (point) (point-max) (erc-timestamp-offset)))
+
+(defun erc-timestamp-offset ()
+  "Get length of timestamp if inserted left."
+  (if (and (boundp 'erc-timestamp-format)
+           erc-timestamp-format
+           (eq erc-insert-timestamp-function 'erc-insert-timestamp-left)
+           (not erc-hide-timestamps))
+      (length (format-time-string erc-timestamp-format))
+    0))
+
+(defun erc-restore-text-properties ()
+  "Restore the property 'erc-parsed for the region."
+  (let* ((parsed-posn (text-property-not-all (point-min) (point-max)
+                                             'erc-parsed nil))
+         (parsed-prop (when parsed-posn
+                        (get-text-property parsed-posn 'erc-parsed))))
+    (put-text-property (point-min) (point-max) 'erc-parsed parsed-prop)))
 
 (provide 'erc-fill)
 
 ;;; erc-fill.el ends here
+;; Local Variables:
+;; indent-tabs-mode: nil
+;; End:
