@@ -1,6 +1,7 @@
 ;;; erc-pcomplete.el --- Provides programmable completion for ERC
 
-;; Copyright (C) 2002  Free Software Foundation, Inc.
+;; Copyright (C) 2002,2003,2004 Free Software Foundation, Inc.
+;; Copyright (C) 2004 Jeremy Bertram Maitin-Shepard
 
 ;; Author: Sacha Chua <sacha@free.net.ph>
 ;; Keywords: comm, convenience
@@ -17,25 +18,22 @@
 ;; GNU General Public License for more details.
 
 ;; You should have received a copy of the GNU General Public License
-;; along with GNU Emacs; see the file COPYING.  If not, write to
-;; the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-;; Boston, MA 02111-1307, USA.
+;; along with GNU Emacs; see the file COPYING. If not, write to the
+;; Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+;; Boston, MA 02110-1301 USA
 
 ;;; Commentary:
 
 ;; This file replaces erc-complete.el.  It provides nick completion
 ;; for ERC based on pcomplete.  If you do not have pcomplete, you may
-;; try to to erc-complete.el.
+;; try to use erc-complete.el.
 ;;
 ;; To use, (require 'erc-auto) or (require 'erc-pcomplete), then
 ;;   (erc-pcomplete-mode 1)
 ;;
-;; If you want erc-pcomplete to list the most recent speakers first,
-;; add the following line to your .emacs after loading the erc-pcomplete
-;; module.
-;;
-;;   (add-hook 'erc-server-PRIVMSG-hook
-;;             'erc-pcomplete-ordering-PRIVMSG-handler)
+;; If you want nickname completions ordered such that the most recent
+;; speakers are listed first, set
+;; `erc-pcomplete-order-nickname-completions' to `t'.
 ;;
 ;; See CREDITS for other contributors.
 ;;
@@ -44,16 +42,28 @@
 (require 'pcomplete)
 (require 'erc)
 (require 'erc-compat)
+(require 'time-date)
+(eval-when-compile (require 'cl))
 
-(defconst erc-pcomplete-version "$Revision: 1.22 $"
+(defconst erc-pcomplete-version "$Revision: 1.32 $"
   "ERC pcomplete mode revision")
 
+(defgroup erc-pcomplete nil
+  "Programmable completion for ERC"
+  :group 'erc)
+
 (defcustom erc-pcomplete-nick-postfix ": "
   "*When `pcomplete' is used in the first word after the prompt,
 add this string to nicks completed."
-  :group 'erc
+  :group 'erc-pcomplete
   :type 'string)
 
+(defcustom erc-pcomplete-order-nickname-completions t
+  "If t, channel nickname completions will be ordered such that
+the most recent speakers are listed first."
+  :group 'erc-pcomplete
+  :type 'boolean)
+
 ;;;###autoload (autoload 'erc-completion-mode "erc-pcomplete" nil t)
 (define-erc-module pcomplete Completion
   "In ERC Completion mode, the TAB key does completion whenever possible."
@@ -68,8 +78,8 @@ add this string to nicks completed."
   (interactive)
   (when (> (point) (erc-beg-of-input-line))
     (let ((last-command (if (eq last-command 'erc-complete-word)
-			    'pcomplete
-			  last-command)))
+                            'pcomplete
+                          last-command)))
       (call-interactively 'pcomplete))
     t))
 
@@ -100,6 +110,13 @@ add this string to nicks completed."
     (pcomplete-erc-commands)
     (pcomplete-erc-nicks erc-pcomplete-nick-postfix))))
 
+(defvar erc-pcomplete-ctcp-commands
+  '("ACTION" "CLIENTINFO" "ECHO" "FINGER" "PING" "TIME" "USERINFO" "VERSION"))
+
+(defun pcomplete/erc-mode/CTCP ()
+  (pcomplete-here (pcomplete-erc-nicks))
+  (pcomplete-here erc-pcomplete-ctcp-commands))
+
 (defun pcomplete/erc-mode/CLEARTOPIC ()
   (pcomplete-here (pcomplete-erc-channels)))
 
@@ -133,7 +150,7 @@ add this string to nicks completed."
 
 (defun pcomplete/erc-mode/MSG ()
   (pcomplete-here (append (pcomplete-erc-all-nicks)
-			  (pcomplete-erc-channels)))
+                          (pcomplete-erc-channels)))
   (while (pcomplete-here (pcomplete-erc-nicks))))
 
 (defun pcomplete/erc-mode/NAMES ()
@@ -151,7 +168,7 @@ add this string to nicks completed."
 
 (defun pcomplete/erc-mode/QUERY ()
   (pcomplete-here (append (pcomplete-erc-all-nicks)
-			  (pcomplete-erc-channels)))
+                          (pcomplete-erc-channels)))
   (while (pcomplete-here (pcomplete-erc-nicks)))
   )
 
@@ -173,43 +190,52 @@ add this string to nicks completed."
   "Returns a list of strings of the defined user commands."
   (let ((case-fold-search nil))
     (mapcar (lambda (x)
-	      (concat "/" (downcase (substring (symbol-name x) 8))))
-	    (apropos-internal "erc-cmd-[A-Z]+"))))
+              (concat "/" (downcase (substring (symbol-name x) 8))))
+            (apropos-internal "erc-cmd-[A-Z]+"))))
 
 (defun pcomplete-erc-ops ()
   "Returns a list of nicks with ops."
-  (mapcar (lambda (x)
-	    (if (car (cdr x)) (car x))) channel-members))
+  (let (ops)
+    (maphash (lambda (nick cdata)
+               (if (and (cdr cdata)
+                        (erc-channel-user-op (cdr cdata)))
+                   (setq ops (cons nick ops))))
+             erc-channel-users)
+    ops))
 
 (defun pcomplete-erc-not-ops ()
   "Returns a list of nicks without ops."
-  (mapcar (lambda (x)
-	    (if (not (car (cdr x))) (car x))) channel-members))
+  (let (not-ops)
+    (maphash (lambda (nick cdata)
+               (if (and (cdr cdata)
+                        (not (erc-channel-user-op (cdr cdata))))
+                   (setq not-ops (cons nick not-ops))))
+             erc-channel-users)
+    not-ops))
+
 
 (defun pcomplete-erc-nicks (&optional postfix)
   "Returns a list of nicks in the current channel."
+  (let ((users (erc-get-channel-user-list)))
+    (if erc-pcomplete-order-nickname-completions
+        (setq users (erc-sort-channel-users-by-activity users)))
   (mapcar (lambda (x)
-	    (if (car x)
-		(concat (car x) postfix)))
-	  channel-members))
+              (concat (erc-server-user-nickname (car x)) postfix))
+            users)))
 
 (defun pcomplete-erc-all-nicks (&optional postfix)
-  "Returns a list of all nicks on the current current server."
-  (let (res)
-    (mapc
-     (lambda (buf)
-       (with-current-buffer buf
-	 (mapc (lambda (elt)
-                 (if (car elt)
-		     (add-to-list 'res (concat (car elt) postfix) res)))
-               channel-members)))
-     (erc-channel-list erc-process))
-    res))
+  "Returns a list of all nicks on the current server."
+  (let (nicks)
+    (with-current-buffer (process-buffer erc-server-process)
+      (maphash (lambda (nick user)
+                 (setq nicks (cons (concat nick postfix) nicks)))
+               erc-server-users))
+      nicks))
 
 (defun pcomplete-erc-channels ()
   "Returns a list of channels associated with the current server."
   (mapcar (lambda (buf) (with-current-buffer buf (erc-default-target)))
-	  (erc-channel-list erc-process)))
+          (erc-channel-list erc-server-process)))
 
 ;;; Functions for parsing
 
@@ -223,68 +249,27 @@ add this string to nicks completed."
   "Returns a list of parsed whitespace-separated arguments.
 These are the words from the beginning of the line after the prompt
 up to where point is right now."
-  (let* ((start (save-excursion (erc-bol) (point)))
-	 (end (point))
-	 args beginnings)
+  (let* ((start erc-input-marker)
+         (end (point))
+         args beginnings)
     (save-excursion
       (if (< (skip-chars-backward " \t\n" start) 0)
-	  (setq args '("")
-		beginnings (list end)))
+          (setq args '("")
+                beginnings (list end)))
       (setq end (point))
       (while (< (skip-chars-backward "^ \t\n" start) 0)
-	(setq beginnings (cons (point) beginnings)
-	      args (cons (buffer-substring-no-properties
-			  (point) end)
-			 args))
-	(skip-chars-backward " \t\n" start)
-	(setq end (point))))
+        (setq beginnings (cons (point) beginnings)
+              args (cons (buffer-substring-no-properties
+                          (point) end)
+                         args))
+        (skip-chars-backward " \t\n" start)
+        (setq end (point))))
     (cons args beginnings)))
 
-;;; Functions to order nick completions such that the most recent
-;;; speakers are listed first.
-
-(defun erc-pcomplete-bring-channel-member-to-front (nick)
-  "Brings the entry `channel-members' for NICK to the front of the list.
-This function should be called with the current buffer set to the
-appropriate channel buffer.
-See also `erc-pcomplete-ordering-PRIVMSG-handler'."
-  (setq nick (erc-downcase nick))
-  (let* ((names-list (erc-get-current-channel-members))
-         (names names-list)
-         temp-var)
-    (when (and names
-               (not (string= nick (erc-downcase (caar names)))))
-      (catch 'done
-        (while (cdr names)
-          (if (string= nick (erc-downcase (caadr names)))
-              (throw 'done nil)
-            (setq names (cdr names)))))
-      (when (cdr names)
-        (setq channel-members (cons (cadr names) names-list))
-        (setcdr names (cddr names))))))
-
-(defun erc-pcomplete-ordering-PRIVMSG-handler (proc parsed)
-  "Calls `erc-pcomplete-bring-channel-member-to-front' with the
-nickname of the sender, if this PRIVMSG is an unignored channel
-message.  Always returns `nil' so that it can conveniently be
-used in server message hooks.  If this is added to
-`erc-server-PRIVMSG-hook', nickname completions will be ordered
-such that the most recent speakers are listed first."
-  (let ((sender-spec (aref parsed 1))
-        (cmd (aref parsed 0))
-        (tgt (aref parsed 2))
-        (msg (aref parsed 3)))
-    (if (and (not (or (erc-ignored-user-p sender-spec)
-                      (erc-ignored-reply-p msg tgt proc)))
-             (erc-channel-p tgt))
-        (let* ((sndr (erc-parse-user sender-spec))
-               (nick (car sndr))
-               (buffer  (erc-get-buffer tgt proc)))
-          (if buffer
-              (with-current-buffer buffer
-                (erc-pcomplete-bring-channel-member-to-front nick))))))
-  nil)
-
 (provide 'erc-pcomplete)
 
 ;;; erc-pcomplete.el ends here
+;;
+;; Local Variables:
+;; indent-tabs-mode: nil
+;; End:
